@@ -202,6 +202,12 @@ impl<U> MemAccess for MmapAccessor<U> {
 
     delegate! {
         to self.accessor {
+            fn addr(&self) -> usize;
+            fn size(&self) -> usize;
+        
+            unsafe fn copy_to<V>(&self, src_adr: usize, dst_ptr: *mut V, count: usize);
+            unsafe fn copy_from<V>(&self, src_ptr: *const V, dst_adr: usize, count: usize);
+            
             unsafe fn write_mem_<V>(&self, offset: usize, data: V);
             unsafe fn read_mem_<V>(&self, offset: usize) -> V;
             unsafe fn write_reg_<V>(&self, reg: usize, data: V);
