@@ -111,7 +111,7 @@ impl<U> UioAccessor<U> {
         })
     }
 
-    pub fn new_from_name(name: &str) -> Result<Self, Box<dyn Error>> {
+    pub fn new_with_name(name: &str) -> Result<Self, Box<dyn Error>> {
         for path in std::fs::read_dir("/sys/class/uio/")? {
             let uio_num: usize = path
                 .unwrap()
@@ -179,6 +179,12 @@ impl<U> MemAccess for UioAccessor<U> {
 
     delegate! {
         to self.mem_accessor {
+            fn addr(&self) -> usize;
+            fn size(&self) -> usize;
+        
+            unsafe fn copy_to<V>(&self, src_adr: usize, dst_ptr: *mut V, count: usize);
+            unsafe fn copy_from<V>(&self, src_ptr: *const V, dst_adr: usize, count: usize);
+            
             unsafe fn write_mem_<V>(&self, offset: usize, data: V);
             unsafe fn read_mem_<V>(&self, offset: usize) -> V;
             unsafe fn write_reg_<V>(&self, reg: usize, data: V);
